==> vue-popconfirm-2.8.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/popconfirm/vue";
import Popover from "@dftvue2-opentiny/vue-popover";
import Modal from "@dftvue2-opentiny/vue-modal";
import Button from "@dftvue2-opentiny/vue-button";
import { iconSuccess, iconInfoSolid, iconWarning, iconError } from "@dftvue2-opentiny/vue-icon";
import "@dftvue2-opentiny/vue-theme/popconfirm/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Popconfirm",
  components: {
    TinyPopover: Popover,
    TinyModal: Modal,
    TinyButton: Button,
    IconSuccess: iconSuccess(),
    IconInfoSolid: iconInfoSolid(),
    IconWarning: iconWarning(),
    IconError: iconError()
  },
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    content: String,
    popperClass: String,
    trigger: {
      type: String,
      default: "hover",
      validator: function validator(value) {
        return Boolean(~["click", "hover"].indexOf(value));
      }
    },
    cancelButton: {
      type: Boolean,
      default: true
    },
    title: String,
    placement: {
      type: String,
      default: "top"
    },
    width: {
      type: [String, Number],
      default: "350"
    },
    type: [String, Object]
  },
  emits: ["hide", "show", "confirm"],
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-popconfirm"
  }, [_c("div", [_c("tiny-popover", {
    ref: "popover",
    attrs: {
      "placement": _vm.placement,
      "trigger": "manual",
      "width": _vm.width,
      "popper-class": _vm.m("tiny-popconfirm-popover", _vm.popperClass)
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("div", {
          staticClass: "tiny-popconfirm__reference",
          on: {
            "click": function click($event) {
              return _vm.show("click");
            },
            "mouseenter": function mouseenter($event) {
              return _vm.show("hover");
            }
          }
        }, [_vm._t("reference")], 2)];
      },
      proxy: true
    }], null, true),
    model: {
      value: _vm.state.showPopover,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "showPopover", $$v);
      },
      expression: "state.showPopover"
    }
  }, [_c("div", {
    staticClass: "tiny-popconfirm-popover__container"
  }, [_c("div", {
    staticClass: "tiny-popconfirm-popover__header"
  }, [_vm.type ? _c(_vm.state.getIcon, {
    tag: "component",
    class: _vm.m("tiny-popconfirm-popover__icon", {
      "fill-color-info-secondary": _vm.type === "info"
    }, {
      "fill-color-error": _vm.type === "error"
    }, {
      "fill-color-warning": _vm.type === "warning"
    }, {
      "fill-color-success": _vm.type === "success"
    })
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-popconfirm-popover__title"
  }, [_vm._v(" " + _vm._s(_vm.title) + " ")])], 1), _c("div", {
    staticClass: "tiny-popconfirm-popover__content"
  }, [_vm._v(" " + _vm._s(_vm.content) + " ")]), _c("div", {
    staticClass: "tiny-popconfirm-popover__footer"
  }, [_vm._t("footer", function() {
    return [_vm.cancelButton ? _c("tiny-button", {
      staticClass: "tiny-popconfirm-popover__cancel-button",
      attrs: {
        "size": "mini"
      },
      on: {
        "click": _vm.hide
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.buttonMessage.cancel")) + " ")]) : _vm._e(), _c("tiny-button", {
      staticClass: "tiny-popconfirm-popover__confirm-button",
      attrs: {
        "size": "mini",
        "type": "primary"
      },
      on: {
        "click": _vm.confirm
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.buttonMessage.confirm")) + " ")])];
  })], 2)])])], 1)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-popconfirm-2.22.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/popconfirm/vue';
import Popover from '@opentinyvue/vue-popover';
import Button from '@opentinyvue/vue-button';
import { iconSuccess, iconHelp, iconWarningTriangle, iconError } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/popconfirm/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Popconfirm",
  components: {
    TinyPopover: Popover,
    TinyButton: Button,
    IconSuccess: iconSuccess(),
    IconHelp: iconHelp(),
    IconWarningTriangle: iconWarningTriangle(),
    IconError: iconError()
  },
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    popperOptions: Object,
    message: String,
    customClass: String,
    trigger: {
      type: String,
      default: "hover",
      validator: function validator(value) {
        return ["click", "hover"].includes(value);
      }
    },
    cancelButton: {
      type: Boolean,
      default: true
    },
    closeOnClickOutside: {
      type: Boolean,
      default: true
    },
    title: String,
    placement: {
      type: String,
      default: "top"
    },
    width: {
      type: [String, Number],
      default: ""
    },
    type: [String, Object],
    reference: {},
    events: Object,
    popperAppendToBody: {
      type: Boolean,
      default: true
    }
  },
  emits: ["hide", "show", "confirm"],
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-popconfirm"
  }, [_c("div", [_c("tiny-popover", {
    ref: "popover",
    attrs: {
      "placement": _vm.placement,
      "trigger": "manual",
      "width": _vm.width,
      "popper-class": "tiny-popconfirm-popover " + (_vm.customClass || ""),
      "popper-options": _vm.popperOptions,
      "append-to-body": _vm.popperAppendToBody,
      "reference": _vm.reference
    },
    on: {
      "show": function show($event) {
        return _vm.handleEmit("show");
      },
      "hide": function hide($event) {
        return _vm.handleEmit("hide");
      }
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("div", {
          staticClass: "tiny-popconfirm__reference",
          on: {
            "click": function click($event) {
              return _vm.show("click");
            },
            "mouseenter": function mouseenter($event) {
              return _vm.show("hover");
            }
          }
        }, [_vm._t("reference")], 2)];
      },
      proxy: true
    }], null, true),
    model: {
      value: _vm.state.showPopover,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "showPopover", $$v);
      },
      expression: "state.showPopover"
    }
  }, [_c("div", {
    staticClass: "tiny-popconfirm-popover__container"
  }, [_c("div", {
    staticClass: "tiny-popconfirm-popover__header"
  }, [_vm.type ? _c(_vm.state.getIcon, {
    tag: "component",
    class: ["tiny-popconfirm-popover__icon", _vm.type ? "tiny-popconfirm-popover--" + _vm.type : ""]
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-popconfirm-popover__title"
  }, [_vm._v(" " + _vm._s(_vm.title) + " ")])], 1), _c("div", {
    staticClass: "tiny-popconfirm-popover__content"
  }, [_vm._v(" " + _vm._s(_vm.message) + " ")]), _c("div", {
    staticClass: "tiny-popconfirm-popover__footer"
  }, [_vm._t("footer", function() {
    return [_vm.cancelButton ? _c("tiny-button", {
      staticClass: "tiny-popconfirm-popover__cancel-button",
      attrs: {
        "size": "mini"
      },
      on: {
        "click": _vm.hide
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.button.cancel")) + " ")]) : _vm._e(), _c("tiny-button", {
      staticClass: "tiny-popconfirm-popover__confirm-button",
      attrs: {
        "size": "mini",
        "type": "primary"
      },
      on: {
        "click": _vm.confirm
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.button.confirm")) + " ")])];
  })], 2)])])], 1)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
